Fix a latent bug in MinimalActions (created by a recent name change).


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@42829 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/Parse/MinimalAction.cpp b/Parse/MinimalAction.cpp
index 932f8ff..b0dad93 100644
--- a/Parse/MinimalAction.cpp
+++ b/Parse/MinimalAction.cpp
@@ -97,9 +97,9 @@
   return 0;
 }
 
 /// PopScope - When a scope is popped, if any typedefs are now out-of-scope,
 /// they are removed from the IdentifierInfo::FETokenInfo field.
-void MinimalAction::PopScope(SourceLocation Loc, Scope *S) {
+void MinimalAction::ActOnPopScope(SourceLocation Loc, Scope *S) {
   for (Scope::decl_iterator I = S->decl_begin(), E = S->decl_end();
        I != E; ++I) {
     IdentifierInfo &II = *static_cast<IdentifierInfo*>(*I);
@@ -97,9 +97,9 @@
 }
 
-/// PopScope - When a scope is popped, if any typedefs are now out-of-scope,
+/// ActOnPopScope - When a scope is popped, if any typedefs are now out-of-scope,
 /// they are removed from the IdentifierInfo::FETokenInfo field.